Level

Enum Level 

pub enum Level {
    Debug,
    Info,
    Success,
    Warn,
    Error,
    Critical,
    Fatal,
}
Severity levels for log categorization.

Variants represent a standard range of log priorities. This enum implements From<Level> for Cow<'static, str>, allowing it to satisfy the string-based level requirements of the Loggable trait without unnecessary allocations. Represents the severity level of a log message.

Variants



Debug

Designates fine-grained informational events that are most useful to debug an application.



Info

Designates informational messages that highlight the progress of the application at coarse-grained level.



Success

Designates a successful operation or a positive milestone in the application flow.



Warn

Designates potentially harmful situations that should be monitored but do not stop the application.



Error

Designates error events that might still allow the application to continue running.



Critical

Designates severe error events that could lead the application to abort or lose critical functionality.



Fatal

Designates very severe error events that will presumably lead the application to terminate immediately.